@@ -31,8 +31,6 @@ def block_join(contents):
 
 def block_split(lines, tag):
     stag = tag[:2]  # Start of any next tag.
-
-
     contents = {}
     i, j = f2(lines, tag)
 
@@ -80,7 +78,7 @@ def block_split(lines, tag):
 
         def argpost(line, j):
             nx_tag = line.find(stag, j+1)
-            arg1 = line[j+len(tag):nx_tag]
+            arg1 = line[j+len(tag):nx_tag] if nx_tag >= 0 else line[j+len(tag):]
             if nx_tag >= 0:
                 post = line[nx_tag:]
             else:
