@@ -30,10 +30,16 @@ def fix_f(lines, debug):
             comments = [id + c for c in comments]
             if len(comments) > 0:
                 lines2 += comments[0].split("\n")
+
             f = [id + l.strip() for l in funrem.splitlines()]
             f[0] = f[0] + "#!b"
             errm = l_head if len(l_head) > 0 else "Implement function body"
-            f[-1] = f[-1] + f' #!b {errm}'
+
+            """ If function body is more than 1 line long and ends with a return we keep the return. """
+            if len( funrem.strip().splitlines() ) == 1 or not f[-1].strip().startswith("return "):
+                f[-1] = f[-1] + f' #!b {errm}'
+            else:
+                f[-2] = f[-2] + f' #!b {errm}'
             lines2 += f
         else:
             lines2.append(l)
